@@ -50,7 +50,10 @@ let run (g : G.guestfs) root (ops : ops) =
   let do_run ~display ?(warn_failed_no_network = false) cmd =
     let incompatible_fn () =
       let guest_arch = g#inspect_get_arch root in
-      error (f_"host cpu (%s) and guest arch (%s) are not compatible, so you cannot use command line options that involve running commands in the guest.  Use --firstboot scripts instead.")
+      error (f_"host cpu (%s) and guest arch (%s) are not compatible, \
+                so you cannot use command line options that involve \
+                running commands in the guest.  Use --firstboot scripts \
+                instead.")
             Guestfs_config.host_cpu guest_arch
     in
 
@@ -61,105 +64,19 @@ let run (g : G.guestfs) root (ops : ops) =
         debug_logfile ();
         if warn_failed_no_network && not (g#get_network ()) then (
           prerr_newline ();
-          warning (f_"the command may have failed because the network is disabled.  Try either removing ‘--no-network’ or adding ‘--network’ on the command line.");
+          warning (f_"the command may have failed because the network is \
+                      disabled.  Try either removing ‘--no-network’ or \
+                      adding ‘--network’ on the command line.");
           prerr_newline ()
         );
         error (f_"%s: command exited with an error") display
   in
 
-  (* http://distrowatch.com/dwres.php?resource=package-management *)
-  let rec guest_install_command packages =
-    let quoted_args = String.concat " " (List.map quote packages) in
-    match g#inspect_get_package_management root with
-    | "apk" ->
-       sprintf "
-         apk update
-         apk add %s
-       " quoted_args
-    | "apt" ->
-      (* http://unix.stackexchange.com/questions/22820 *)
-      sprintf "
-        export DEBIAN_FRONTEND=noninteractive
-        apt_opts='-q -y -o Dpkg::Options::=--force-confnew'
-        apt-get $apt_opts update
-        apt-get $apt_opts install %s
-      " quoted_args
-    | "dnf" ->
-       sprintf "dnf%s -y install %s"
-               (if verbose () then " --verbose" else "")
-               quoted_args
-    | "pisi" ->   sprintf "pisi it %s" quoted_args
-    | "pacman" -> sprintf "pacman -S --noconfirm %s" quoted_args
-    | "urpmi" ->  sprintf "urpmi %s" quoted_args
-    | "xbps" ->   sprintf "xbps-install -Sy %s" quoted_args
-    | "yum" ->    sprintf "yum -y install %s" quoted_args
-    | "zypper" -> sprintf "zypper -n in -l %s" quoted_args
-
-    | "unknown" ->
-      error_unknown_package_manager (s_"--install")
-    | pm ->
-      error_unimplemented_package_manager (s_"--install") pm
-
-  and guest_update_command () =
-    match g#inspect_get_package_management root with
-    | "apk" ->
-       "
-         apk update
-         apk upgrade
-       "
-    | "apt" ->
-      (* http://unix.stackexchange.com/questions/22820 *)
-      "
-        export DEBIAN_FRONTEND=noninteractive
-        apt_opts='-q -y -o Dpkg::Options::=--force-confnew'
-        apt-get $apt_opts update
-        apt-get $apt_opts upgrade
-      "
-    | "dnf" ->
-       sprintf "dnf%s -y --best upgrade"
-               (if verbose () then " --verbose" else "")
-    | "pisi" ->   "pisi upgrade"
-    | "pacman" -> "pacman -Su"
-    | "urpmi" ->  "urpmi --auto-select"
-    | "xbps" ->   "xbps-install -Suy"
-    | "yum" ->    "yum -y update"
-    | "zypper" -> "zypper -n update -l"
-
-    | "unknown" ->
-      error_unknown_package_manager (s_"--update")
-    | pm ->
-      error_unimplemented_package_manager (s_"--update") pm
-
-  and guest_uninstall_command packages =
-    let quoted_args = String.concat " " (List.map quote packages) in
-    match g#inspect_get_package_management root with
-    | "apk" -> sprintf "apk del %s" quoted_args
-    | "apt" ->
-      (* http://unix.stackexchange.com/questions/22820 *)
-      sprintf "
-        export DEBIAN_FRONTEND=noninteractive
-        apt_opts='-q -y -o Dpkg::Options::=--force-confnew'
-        apt-get $apt_opts remove %s
-      " quoted_args
-    | "dnf" ->    sprintf "dnf -y remove %s" quoted_args
-    | "pisi" ->   sprintf "pisi rm %s" quoted_args
-    | "pacman" -> sprintf "pacman -R %s" quoted_args
-    | "urpmi" ->  sprintf "urpme %s" quoted_args
-    | "xbps" ->   sprintf "xbps-remove -Sy %s" quoted_args
-    | "yum" ->    sprintf "yum -y remove %s" quoted_args
-    | "zypper" -> sprintf "zypper -n rm %s" quoted_args
-
-    | "unknown" ->
-      error_unknown_package_manager (s_"--uninstall")
-    | pm ->
-      error_unimplemented_package_manager (s_"--uninstall") pm
-
-  (* Windows has package_management == "unknown". *)
-  and error_unknown_package_manager flag =
-    error (f_"cannot use ‘%s’ because no package manager has been detected for this guest OS.\n\nIf this guest OS is a common one with ordinary package management then this may have been caused by a failure of libguestfs inspection.\n\nFor OSes such as Windows that lack package management, this is not possible.  Try using one of the ‘--firstboot*’ flags instead (described in the manual).") flag
-
-  and error_unimplemented_package_manager flag pm =
-      error (f_"sorry, ‘%s’ with the ‘%s’ package manager has not been implemented yet.\n\nYou can work around this by using one of the ‘--run*’ or ‘--firstboot*’ options instead (described in the manual).") flag pm
+  let guest_pkgs_command f =
+    try f (g#inspect_get_package_management root) with
+    | Guest_packages.Unknown_package_manager msg
+    | Guest_packages.Unimplemented_package_manager msg ->
+      error "%s" msg
   in
 
   (* Set the random seed. *)
@@ -191,10 +108,28 @@ let run (g : G.guestfs) root (ops : ops) =
   let passwords = Hashtbl.create 13 in
   let set_password user pw =
     if Hashtbl.mem passwords user then
-      error (f_"multiple --root-password/--password options set the password for user ‘%s’ twice") user;
+      error (f_"multiple --root-password/--password options set the \
+                password for user ‘%s’ twice") user;
     Hashtbl.replace passwords user pw
   in
 
+  (* Helper function to convert --inject-qemu-ga/--inject-virtio-win
+   * method parameter into a virtio-win handle.
+   *)
+  let get_virtio_win_handle op meth =
+    if g#inspect_get_type root <> "windows" then (
+        warning (f_"%s ignored for non-Windows guest") op;
+        None
+    )
+    else (
+      match meth with
+      | "osinfo" | "libosinfo" ->
+         Some (Inject_virtio_win.from_libosinfo g root)
+      | path ->
+         Some (Inject_virtio_win.from_path g root path)
+    )
+  in
+
   (* Perform the remaining customizations in command-line order. *)
   List.iter (
     function
@@ -203,7 +138,9 @@ let run (g : G.guestfs) root (ops : ops) =
         * to prevent incorrect line endings being added to a file.
         *)
        if String.contains line '\n' then
-         error (f_"--append-line: line must not contain newline characters.  Use the --append-line option multiple times to add several lines.");
+         error (f_"--append-line: line must not contain newline characters.  \
+                   Use the --append-line option multiple times to add \
+                   several lines.");
 
        message (f_"Appending line to %s") path;
        append_line g root path line
@@ -255,7 +192,7 @@ let run (g : G.guestfs) root (ops : ops) =
     | `FirstbootPackages pkgs ->
       message (f_"Installing firstboot packages: %s")
         (String.concat " " pkgs);
-      let cmd = guest_install_command pkgs in
+      let cmd = guest_pkgs_command (Guest_packages.install_command pkgs) in
       let name = String.concat " " ("install" :: pkgs) in
       Firstboot.add_firstboot_script g root name cmd
 
@@ -269,9 +206,36 @@ let run (g : G.guestfs) root (ops : ops) =
       if not (Hostname.set_hostname g root hostname) then
         warning (f_"hostname could not be set for this type of guest")
 
+    | `InjectQemuGA meth ->
+       (match get_virtio_win_handle "--inject-qemu-ga" meth with
+        | None -> ()
+        | Some t ->
+           if not (Inject_virtio_win.inject_qemu_ga t) then
+             warning (f_"--inject-qemu-ga: QEMU Guest Agent MSI not found in \
+                         virtio-win source that you specified")
+       )
+
+    | `InjectVirtioWin meth ->
+       (match get_virtio_win_handle "--inject-virtio-win" meth with
+        | None -> ()
+        | Some t ->
+           let windows_system_hive = g#inspect_get_windows_system_hive root in
+           Registry.with_hive_write g windows_system_hive (
+             fun reg ->
+               let installed =
+                 Inject_virtio_win.inject_virtio_win_drivers t reg in
+
+               (* Warn if we didn't install at least the virtio-blk driver. *)
+               if installed.block_driver <> Inject_virtio_win.Virtio_blk then
+                 warning (f_"--inject-virtio-win: virtio drivers were not \
+                             found for this Windows version in the \
+                             virtio-win source that you specified")
+             )
+       )
+
     | `InstallPackages pkgs ->
       message (f_"Installing packages: %s") (String.concat " " pkgs);
-      let cmd = guest_install_command pkgs in
+      let cmd = guest_pkgs_command (Guest_packages.install_command pkgs) in
       do_run ~display:cmd ~warn_failed_no_network:true cmd
 
     | `Link (target, links) ->
@@ -321,9 +285,11 @@ let run (g : G.guestfs) root (ops : ops) =
       let creds =
         match ops.flags.sm_credentials with
         | None ->
-          error (f_"subscription-manager credentials required for --sm-register")
+          error (f_"subscription-manager credentials required for \
+                    --sm-register")
         | Some c -> c in
-      let cmd = sprintf "subscription-manager register --username=%s --password=%s"
+      let cmd = sprintf "subscription-manager register \
+                         --username=%s --password=%s"
                   (quote creds.Subscription_manager.sm_username)
                   (quote creds.Subscription_manager.sm_password) in
       do_run ~display:"subscription-manager register"
@@ -365,12 +331,12 @@ let run (g : G.guestfs) root (ops : ops) =
 
     | `UninstallPackages pkgs ->
       message (f_"Uninstalling packages: %s") (String.concat " " pkgs);
-      let cmd = guest_uninstall_command pkgs in
+      let cmd = guest_pkgs_command (Guest_packages.uninstall_command pkgs) in
       do_run ~display:cmd cmd
 
     | `Update ->
       message (f_"Updating packages");
-      let cmd = guest_update_command () in
+      let cmd = guest_pkgs_command Guest_packages.update_command in
       do_run ~display:cmd ~warn_failed_no_network:true cmd
 
     | `Upload (path, dest) ->
@@ -415,7 +381,7 @@ let run (g : G.guestfs) root (ops : ops) =
       warning (f_"passwords could not be set for this type of guest")
   );
 
-  if ops.flags.selinux_relabel then (
+  if not ops.flags.no_selinux_relabel then (
     message (f_"SELinux relabelling");
     SELinux_relabel.relabel g
   );
