@@ -550,7 +550,7 @@ let main () =
   let image_basename_d = image_basename ^ ".d" in
 
   let tmpdir = Mkdtemp.temp_dir "dib." in
-  On_exit.rmdir tmpdir;
+  On_exit.rm_rf tmpdir;
   let auxtmpdir = tmpdir // "in_target.aux" in
   do_mkdir auxtmpdir;
   let hookstmpdir = auxtmpdir // "hooks" in
@@ -721,8 +721,8 @@ let main () =
 
   let g, tmpdisk, tmpdiskfmt, drive_partition =
     let g = open_guestfs () in
-    Option.may g#set_memsize cmdline.memsize;
-    Option.may g#set_smp cmdline.smp;
+    Option.iter g#set_memsize cmdline.memsize;
+    Option.iter g#set_smp cmdline.smp;
     g#set_network cmdline.network;
 
     (* Main disk with the built image. *)
